@@ -1,81 +1,38 @@
-package XML::RSS::Private::Output::V2_0;
-$XML::RSS::Private::Output::V2_0::VERSION = '1.64';
+package XML::RSS::Private::Output::V0_9;
+$XML::RSS::Private::Output::V0_9::VERSION = '1.65';
 use strict;
 use warnings;
 
 use vars (qw(@ISA));
 
-use XML::RSS::Private::Output::Base                ();
-use XML::RSS::Private::Output::Roles::ModulesElems ();
-use XML::RSS::Private::Output::Roles::ImageDims    ();
+use XML::RSS::Private::Output::Base ();
 
-@ISA = (
-    qw(
-      XML::RSS::Private::Output::Roles::ImageDims
-      XML::RSS::Private::Output::Roles::ModulesElems
-      XML::RSS::Private::Output::Base
-      )
-);
+@ISA = (qw(XML::RSS::Private::Output::Base));
 
-sub _get_filtered_items {
-    my $self = shift;
-
-    return [grep { exists($_->{title}) || exists($_->{description}) } @{$self->_get_items()},];
+sub _get_rdf_decl {
+    return qq{<rdf:RDF\nxmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"\n}
+      . qq{xmlns="http://my.netscape.com/rdf/simple/0.9/">\n\n};
 }
 
-sub _out_item_2_0_tags {
-    my ($self, $item) = @_;
-
-    $self->_output_def_item_tag($item, "author");
-    $self->_output_array_item_tag($item, "category");
-    $self->_output_def_item_tag($item, "comments");
-
-    $self->_out_guid($item);
-
-    $self->_output_def_item_tag($item, "pubDate");
-
-    $self->_out_item_source($item);
-
-    $self->_out_item_enclosure($item);
+# 'description' for item does not exist in RSS 0.9
+sub _out_item_desc {
+    return;
 }
 
-sub _get_textinput_tag {
-    return "textInput";
-}
-
-sub _get_item_defined {
-    return 1;
+# RSS 0.9 does not support the language tag so we nullify this tag.
+sub _out_language {
+    return;
 }
 
 sub _output_rss_middle {
     my $self = shift;
 
-    # PICS rating
-    # Not supported by RSS 2.0
-    # $output .= '<rating>'.$self->{channel}->{rating}.'</rating>'."\n"
-    #    if $self->{channel}->{rating};
+    $self->_end_channel();
+    $self->_output_main_elements;
+}
 
-    # copyright
-    $self->_out_copyright();
-
-    $self->_out_dates();
-
-    # external CDF URL
-    $self->_out_def_chan_tag("docs");
-
-    $self->_out_editors;
-
-    $self->_out_channel_array_self_dc_field("category");
-    $self->_out_channel_self_dc_field("generator");
-
-    # Insert cloud support here
-
-    # ttl
-    $self->_out_channel_self_dc_field("ttl");
-
-    $self->_out_modules_elements($self->channel());
-
-    $self->_out_last_elements;
+sub _get_end_tag {
+    return "rdf:RDF";
 }
 
 1;
@@ -88,7 +45,7 @@ __END__
 
 =head1 VERSION
 
-version 1.64
+version 1.65
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
